@@ -3,7 +3,7 @@ package Complete::TZ;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-02-27'; # DATE
 our $DIST = 'Complete-TZ'; # DIST
-our $VERSION = '0.080'; # VERSION
+our $VERSION = '0.081'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,7 @@ use warnings;
 
 use Complete::Common qw(:all);
 use Complete::Util qw(hashify_answer);
+use Sah::Schema::date::tz_offset;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -22,15 +23,6 @@ our @EXPORT_OK = qw(
 
 our %SPEC;
 
-# taken from Wikipedia page: https://en.wikipedia.org/wiki/UTC%2B14:00 on Feb 27, 2020
-our @TZ_OFFSETS = qw(
-    −12:00 −11:00 −10:30 −10:00 −09:30 −09:00 −08:30 −08:00 −07:00
-    −06:00 −05:00 −04:30 −04:00 −03:30 −03:00 −02:30 −02:00 −01:00 −00:44 −00:25:21
-    -00:00 +00:00 +00:20 +00:30 +01:00 +01:24 +01:30 +02:00 +02:30 +03:00 +03:30 +04:00 +04:30 +04:51 +05:00 +05:30 +05:40 +05:45
-    +06:00 +06:30 +07:00 +07:20 +07:30 +08:00 +08:30 +08:45 +09:00 +09:30 +09:45 +10:00 +10:30 +11:00 +11:30
-    +12:00 +12:45 +13:00 +13:45 +14:00
-);
-
 $SPEC{':package'} = {
     v => 1.1,
     summary => 'Timezone-related completion routines',
@@ -99,7 +91,7 @@ sub complete_tz_offset {
 
     Complete::Util::complete_array_elem(
         word => $word,
-        array => \@TZ_OFFSETS,
+        array => \@Sah::Schema::date::tz_offset::TZ_STRING_OFFSETS,
     );
 }
 
@@ -118,7 +110,7 @@ Complete::TZ - Timezone-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.080 of Complete::TZ (from Perl distribution Complete-TZ), released on 2020-02-27.
+This document describes version 0.081 of Complete::TZ (from Perl distribution Complete-TZ), released on 2020-02-27.
 
 =head1 DESCRIPTION
 
